<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class MODULE_admin extends \Ciext\Controller\AbstractAdminController
{

    public function index()
    {
        return array('content' => 'MODULE', 'title' => $this->lang->line('MODULE'));
    }

}
