<div class="alert alert-success"><button type="button" class="close" data-dismiss="alert">&times;</button><?php echo $this->lang->line('CRUD was successfully generated'); ?></div>
<div class="control-group">
    <h4><?php echo $this->lang->line('For run CRUD add the following code to yours admin controller'); ?></h4>
    <pre class="pre-scrollable">
        $this->load->model('<?php echo $this->input->post('module_folder'); ?>/<?php echo $this->input->post('crud_file'); ?>');

        return array('content' => $this-><?php echo $this->input->post('crud_file'); ?>->render(), 'title' => $this->lang->line('CRUD title page'));
    </pre>
</div>
<div class="control-group">
    <h4><?php echo $this->lang->line('Crud model'); ?> : {crud_model_file}</h4>
    <pre class="pre-scrollable">{crud_model_data}</pre>
</div>
<div class="control-group">
    <h4><?php echo $this->lang->line('Crud schema file'); ?> : {crud_schema_file}</h4>
    <pre class="pre-scrollable">{crud_schema_data}</pre>
</div>